@@ -18,8 +18,11 @@ import os
 import sys
 
 from flake8.api.legacy import get_style_guide
+import pytest
 
 
+@pytest.mark.flake8
+@pytest.mark.linter
 def test_flake8():
     # Configure flake8 using the .flake8 file in the root of this repository.
     style_guide = get_style_guide()
